aboutsummaryrefslogtreecommitdiff
path: root/engines/tinsel
diff options
context:
space:
mode:
Diffstat (limited to 'engines/tinsel')
-rw-r--r--engines/tinsel/actors.cpp2
-rw-r--r--engines/tinsel/background.cpp2
-rw-r--r--engines/tinsel/background.h2
-rw-r--r--engines/tinsel/bg.cpp8
-rw-r--r--engines/tinsel/bmv.cpp12
-rw-r--r--engines/tinsel/bmv.h4
-rw-r--r--engines/tinsel/cliprect.cpp2
-rw-r--r--engines/tinsel/cursor.cpp24
-rw-r--r--engines/tinsel/dialogs.cpp2
-rw-r--r--engines/tinsel/heapmem.cpp4
-rw-r--r--engines/tinsel/heapmem.h4
-rw-r--r--engines/tinsel/multiobj.cpp2
-rw-r--r--engines/tinsel/multiobj.h2
-rw-r--r--engines/tinsel/object.cpp6
-rw-r--r--engines/tinsel/pcode.cpp4
-rw-r--r--engines/tinsel/pcode.h2
-rw-r--r--engines/tinsel/polygons.cpp22
-rw-r--r--engines/tinsel/savescn.cpp4
-rw-r--r--engines/tinsel/savescn.h2
-rw-r--r--engines/tinsel/scene.cpp12
-rw-r--r--engines/tinsel/scroll.cpp2
-rw-r--r--engines/tinsel/sysvar.cpp2
-rw-r--r--engines/tinsel/tinlib.cpp4
-rw-r--r--engines/tinsel/tinsel.cpp2
24 files changed, 66 insertions, 66 deletions
diff --git a/engines/tinsel/actors.cpp b/engines/tinsel/actors.cpp
index 9caa12d320..4e9847f8b4 100644
--- a/engines/tinsel/actors.cpp
+++ b/engines/tinsel/actors.cpp
@@ -434,7 +434,7 @@ void StartTaggedActors(SCNHANDLE ah, int numActors, bool bRunScript) {
memset(taggedActors, 0, sizeof(taggedActors));
numTaggedActors = numActors;
} else {
- // Only actors with code blocks got (x, y) re-initialised, so...
+ // Only actors with code blocks got (x, y) re-initialized, so...
for (i = 0; i < NumActors; i++) {
actorInfo[i].x = actorInfo[i].y = 0;
actorInfo[i].mtype = 0;
diff --git a/engines/tinsel/background.cpp b/engines/tinsel/background.cpp
index 5e2ebaafdc..72397db97f 100644
--- a/engines/tinsel/background.cpp
+++ b/engines/tinsel/background.cpp
@@ -37,7 +37,7 @@ namespace Tinsel {
const BACKGND *pCurBgnd = NULL;
/**
- * Called to initialise a background.
+ * Called to initialize a background.
* @param pBgnd Pointer to data struct for current background
*/
diff --git a/engines/tinsel/background.h b/engines/tinsel/background.h
index 37ab4d4d5c..34f1bd6dd2 100644
--- a/engines/tinsel/background.h
+++ b/engines/tinsel/background.h
@@ -73,7 +73,7 @@ struct BACKGND {
|* Background Function Prototypes *|
\*----------------------------------------------------------------------*/
-void InitBackground( // called to initialise a background
+void InitBackground( // called to initialize a background
const BACKGND *pBgnd); // pointer to data struct for current background
void StartupBackground(CORO_PARAM, SCNHANDLE hFilm);
diff --git a/engines/tinsel/bg.cpp b/engines/tinsel/bg.cpp
index e5618afc5c..cf692e16ea 100644
--- a/engines/tinsel/bg.cpp
+++ b/engines/tinsel/bg.cpp
@@ -126,7 +126,7 @@ static void BGmainProcess(CORO_PARAM, const void *param) {
// Get the MULTI_INIT structure
pmi = (const MULTI_INIT *)LockMem(FROM_LE_32(pReel->mobj));
- // Initialise and insert the object, and initialise its script.
+ // Initialize and insert the object, and initialize its script.
pBG[0] = MultiInitObject(pmi);
MultiInsertObject(GetPlayfieldList(FIELD_WORLD), pBG[0]);
InitStepAnimScript(&thisAnim[0], pBG[0], FROM_LE_32(pReel->script), BGspeed);
@@ -141,7 +141,7 @@ static void BGmainProcess(CORO_PARAM, const void *param) {
// Get the MULTI_INIT structure
pmi = (PMULTI_INIT) LockMem(FROM_LE_32(pFilm->reels[i].mobj));
- // Initialise and insert the object, and initialise its script.
+ // Initialize and insert the object, and initialize its script.
pBG[i] = MultiInitObject(pmi);
MultiInsertObject(GetPlayfieldList(FIELD_WORLD), pBG[i]);
MultiSetZPosition(pBG[i], 0);
@@ -176,7 +176,7 @@ static void BGmainProcess(CORO_PARAM, const void *param) {
pFilm = (const FILM *)LockMem(hBackground);
assert(bgReels == (int32)FROM_LE_32(pFilm->numreels));
- // Just re-initialise the scripts.
+ // Just re-initialize the scripts.
for (int i = 0; i < bgReels; i++) {
InitStepAnimScript(&thisAnim[i], pBG[i], pFilm->reels[i].script, BGspeed);
StepAnimScript(&thisAnim[i]);
@@ -202,7 +202,7 @@ static void BGotherProcess(CORO_PARAM, const void *param) {
CORO_BEGIN_CODE(_ctx);
- // Initialise and insert the object, and initialise its script.
+ // Initialize and insert the object, and initialize its script.
_ctx->pObj = MultiInitObject(pmi);
MultiInsertObject(GetPlayfieldList(FIELD_WORLD), _ctx->pObj);
diff --git a/engines/tinsel/bmv.h b/engines/tinsel/bmv.h
index 02ba6d100f..eadf65c3aa 100644
--- a/engines/tinsel/bmv.h
+++ b/engines/tinsel/bmv.h
@@ -134,7 +134,7 @@ private:
void InitBMV(byte *memoryBuffer);
void PrepAudio(const byte *sourceData, int blobCount, byte *destPtr);
void MoviePalette(int paletteOffset);
- void InitialiseMovieSound();
+ void InitializeMovieSound();
void StartMovieSound();
void FinishMovieSound();
void MovieAudio(int audioOffset, int blobs);
@@ -144,7 +144,7 @@ private:
int MovieCommand(char cmd, int commandOffset);
int FollowingPacket(int thisPacket, bool bReallyImportant);
void LoadSlots(int number);
- void InitialiseBMV();
+ void InitializeBMV();
bool MaintainBuffer();
bool DoBMVFrame();
bool DoSoundFrame();
diff --git a/engines/tinsel/cliprect.cpp b/engines/tinsel/cliprect.cpp
index f8d8011b12..76feede83f 100644
--- a/engines/tinsel/cliprect.cpp
+++ b/engines/tinsel/cliprect.cpp
@@ -209,7 +209,7 @@ void UpdateClipRect(OBJECT **pObjList, Common::Point *pWin, Common::Rect *pClip)
DRAWOBJECT currentObj; // filled in to draw the current object in list
OBJECT *pObj; // object list iterator
- // Initialise the fields of the drawing object to empty
+ // Initialize the fields of the drawing object to empty
memset(&currentObj, 0, sizeof(DRAWOBJECT));
for (pObj = *pObjList; pObj != NULL; pObj = pObj->pNext) {
diff --git a/engines/tinsel/cursor.cpp b/engines/tinsel/cursor.cpp
index 6e04feff57..8248609a81 100644
--- a/engines/tinsel/cursor.cpp
+++ b/engines/tinsel/cursor.cpp
@@ -77,7 +77,7 @@ static int nextTrail = 0;
static bool bWhoa = false; // Set by DropCursor() at the end of a scene
// - causes cursor processes to do nothing
- // Reset when main cursor has re-initialised
+ // Reset when main cursor has re-initialized
static uint16 restart = 0; // When main cursor has been bWhoa-ed, it waits
// for this to be set to 0x8000.
@@ -106,8 +106,8 @@ static int lastCursorX = 0, lastCursorY = 0;
static void DoCursorMove();
/**
- * Initialise and insert a cursor trail object, set its Z-pos, and hide
- * it. Also initialise its animation script.
+ * Initialize and insert a cursor trail object, set its Z-pos, and hide
+ * it. Also initialize its animation script.
*/
static void InitCurTrailObj(int i, int x, int y) {
const FREEL *pfr; // pointer to reel
@@ -127,13 +127,13 @@ static void InitCurTrailObj(int i, int x, int y) {
assert(BgPal()); // No background palette
pim->hImgPal = TO_LE_32(BgPal());
- // Initialise and insert the object, set its Z-pos, and hide it
+ // Initialize and insert the object, set its Z-pos, and hide it
ntrailData[i].trailObj = MultiInitObject(pmi);
MultiInsertObject(GetPlayfieldList(FIELD_STATUS), ntrailData[i].trailObj);
MultiSetZPosition(ntrailData[i].trailObj, Z_CURSORTRAIL);
MultiSetAniXY(ntrailData[i].trailObj, x, y);
- // Initialise the animation script
+ // Initialize the animation script
InitStepAnimScript(&ntrailData[i].trailAnim, ntrailData[i].trailObj, FROM_LE_32(pfr->script), ONE_SECOND / FROM_LE_32(pfilm->frate));
StepAnimScript(&ntrailData[i].trailAnim);
}
@@ -227,7 +227,7 @@ void GetCursorXY(int *x, int *y, bool absolute) {
}
/**
- * Re-initialise the main cursor to use the main cursor reel.
+ * Re-initialize the main cursor to use the main cursor reel.
* Called from TINLIB.C to restore cursor after hiding it.
* Called from INVENTRY.C to restore cursor after customising it.
*/
@@ -385,11 +385,11 @@ void SetAuxCursor(SCNHANDLE hFilm) {
ACoY = (short)((FROM_LE_16(pim->imgHeight) & ~C16_FLAG_MASK)/2 -
((int16) FROM_LE_16(pim->anioffY)));
- // Initialise and insert the auxillary cursor object
+ // Initialize and insert the auxillary cursor object
AcurObj = MultiInitObject(pmi);
MultiInsertObject(GetPlayfieldList(FIELD_STATUS), AcurObj);
- // Initialise the animation and set its position
+ // Initialize the animation and set its position
InitStepAnimScript(&AcurAnim, AcurObj, FROM_LE_32(pfr->script), ONE_SECOND / FROM_LE_32(pfilm->frate));
MultiSetAniXY(AcurObj, x - ACoX, y - ACoY);
MultiSetZPosition(AcurObj, Z_ACURSOR);
@@ -470,7 +470,7 @@ static void DoCursorMove() {
}
/**
- * Initialise cursor object.
+ * Initialize cursor object.
*/
static void InitCurObj() {
const FILM *pFilm;
@@ -500,7 +500,7 @@ static void InitCurObj() {
}
/**
- * Initialise the cursor position.
+ * Initialize the cursor position.
*/
static void InitCurPos() {
Common::Point ptMouse = _vm->getMousePosition();
@@ -530,7 +530,7 @@ static void CursorStoppedCheck(CORO_PARAM) {
while (restart != 0x8000)
CORO_SLEEP(1);
- // Re-initialise
+ // Re-initialize
InitCurObj();
InitCurPos();
InventoryIconCursor(false); // May be holding something
@@ -656,7 +656,7 @@ void DropCursor() {
* RestartCursor is called when a new scene is starting up.
*/
void RestartCursor() {
- restart = 0x8000; // Get the main cursor to re-initialise
+ restart = 0x8000; // Get the main cursor to re-initialize
}
/**
diff --git a/engines/tinsel/dialogs.cpp b/engines/tinsel/dialogs.cpp
index 6deeab27cd..6ca070b67a 100644
--- a/engines/tinsel/dialogs.cpp
+++ b/engines/tinsel/dialogs.cpp
@@ -1319,7 +1319,7 @@ extern int WhichItemHeld() {
}
/**
- * Called from the cursor module when it re-initialises (at the start of
+ * Called from the cursor module when it re-initializes (at the start of
* a new scene). For if we are holding something at scene-change time.
*/
extern void InventoryIconCursor(bool bNewItem) {
diff --git a/engines/tinsel/heapmem.cpp b/engines/tinsel/heapmem.cpp
index 2376583222..026dc9457e 100644
--- a/engines/tinsel/heapmem.cpp
+++ b/engines/tinsel/heapmem.cpp
@@ -100,7 +100,7 @@ static void MemoryStats() {
#endif
/**
- * Initialises the memory manager.
+ * Initializes the memory manager.
*/
void MemoryInit() {
// place first node on free list
@@ -133,7 +133,7 @@ void MemoryInit() {
}
/**
- * Deinitialises the memory manager.
+ * Deinitializes the memory manager.
*/
void MemoryDeinit() {
const MEM_NODE *pHeap = &heapSentinel;
diff --git a/engines/tinsel/heapmem.h b/engines/tinsel/heapmem.h
index 277463e4ef..7b29a3ecce 100644
--- a/engines/tinsel/heapmem.h
+++ b/engines/tinsel/heapmem.h
@@ -35,8 +35,8 @@ struct MEM_NODE;
|* Memory Function Prototypes *|
\*----------------------------------------------------------------------*/
-void MemoryInit(); // initialises the memory manager
-void MemoryDeinit(); // deinitialises the memory manager
+void MemoryInit(); // initializes the memory manager
+void MemoryDeinit(); // deinitializes the memory manager
// reserves a memory node for a movable & discardable block
MEM_NODE *MemoryNoAlloc();
diff --git a/engines/tinsel/multiobj.cpp b/engines/tinsel/multiobj.cpp
index 4a9d4b65d4..c48fefdd22 100644
--- a/engines/tinsel/multiobj.cpp
+++ b/engines/tinsel/multiobj.cpp
@@ -29,7 +29,7 @@
namespace Tinsel {
/**
- * Initialise a multi-part object using a list of images to init
+ * Initialize a multi-part object using a list of images to init
* each object piece. One object is created for each image in the list.
* All objects are given the same palette as the first image. A pointer
* to the first (master) object created is returned.
diff --git a/engines/tinsel/multiobj.h b/engines/tinsel/multiobj.h
index a467fac425..a0f977553a 100644
--- a/engines/tinsel/multiobj.h
+++ b/engines/tinsel/multiobj.h
@@ -53,7 +53,7 @@ typedef MULTI_INIT *PMULTI_INIT;
|* Multi Object Function Prototypes *|
\*----------------------------------------------------------------------*/
-OBJECT *MultiInitObject( // Initialise a multi-part object
+OBJECT *MultiInitObject( // Initialize a multi-part object
const MULTI_INIT *pInitTbl); // pointer to multi-object initialisation table
void MultiInsertObject( // Insert a multi-part object onto a object list
diff --git a/engines/tinsel/object.cpp b/engines/tinsel/object.cpp
index b1090058d1..cbe5b0a88f 100644
--- a/engines/tinsel/object.cpp
+++ b/engines/tinsel/object.cpp
@@ -345,7 +345,7 @@ void GetAniPosition(OBJECT *pObj, int *pPosX, int *pPosY) {
}
/**
- * Initialise a object using a OBJ_INIT structure to supply parameters.
+ * Initialize a object using a OBJ_INIT structure to supply parameters.
* @param pInitTbl Pointer to object initialisation table
*/
OBJECT *InitObject(const OBJ_INIT *pInitTbl) {
@@ -486,7 +486,7 @@ void AnimateObject(OBJECT *pAniObj, SCNHANDLE hNewImg) {
* @param height Height of rectangle
*/
OBJECT *RectangleObject(SCNHANDLE hPal, int color, int width, int height) {
- // template for initialising the rectangle object
+ // template for initializing the rectangle object
static const OBJ_INIT rectObj = {0, DMA_CONST, OID_EFFECTS, 0, 0, 0};
PALQ *pPalQ; // palette queue pointer
@@ -522,7 +522,7 @@ OBJECT *RectangleObject(SCNHANDLE hPal, int color, int width, int height) {
* @param height Height of rectangle
*/
OBJECT *TranslucentObject(int width, int height) {
- // template for initialising the rectangle object
+ // template for initializing the rectangle object
static const OBJ_INIT rectObj = {0, DMA_TRANS, OID_EFFECTS, 0, 0, 0};
// allocate and init a new object
diff --git a/engines/tinsel/pcode.cpp b/engines/tinsel/pcode.cpp
index 39423813bf..0834e7df24 100644
--- a/engines/tinsel/pcode.cpp
+++ b/engines/tinsel/pcode.cpp
@@ -348,7 +348,7 @@ void FreeMasterInterpretContext() {
}
/**
- * Allocate and initialise an interpret context.
+ * Allocate and initialize an interpret context.
* Called from a process prior to Interpret().
* @param gsort which sort of code
* @param hCode Handle to code to execute
@@ -385,7 +385,7 @@ INT_CONTEXT *InitInterpretContext(GSORT gsort, SCNHANDLE hCode, TINSEL_EVENT eve
}
/**
- * Allocate and initialise an interpret context with restored data.
+ * Allocate and initialize an interpret context with restored data.
*/
INT_CONTEXT *RestoreInterpretContext(INT_CONTEXT *ric) {
INT_CONTEXT *ic;
diff --git a/engines/tinsel/pcode.h b/engines/tinsel/pcode.h
index eedf9fb827..971a42d7bd 100644
--- a/engines/tinsel/pcode.h
+++ b/engines/tinsel/pcode.h
@@ -74,7 +74,7 @@ struct INT_CONTEXT {
int ip; ///< instruction pointer
bool bHalt; ///< set to exit interpeter
bool escOn;
- int myEscape; ///< only initialised to prevent compiler warning!
+ int myEscape; ///< only initialized to prevent compiler warning!
uint32 waitNumber1; // The waiting numbert
uint32 waitNumber2; // The wait for number
diff --git a/engines/tinsel/polygons.cpp b/engines/tinsel/polygons.cpp
index 26a861f692..6fc1c65ec5 100644
--- a/engines/tinsel/polygons.cpp
+++ b/engines/tinsel/polygons.cpp
@@ -1275,13 +1275,13 @@ HPOLYGON GetPolyHandle(int i) {
// **************************************************************************
//
-// Code called to initialise or wrap up a scene:
+// Code called to initialize or wrap up a scene:
//
// **************************************************************************
/**
* Called at the start of a scene, when all polygons have been
- * initialised, to work out which paths are adjacent to which.
+ * initialized, to work out which paths are adjacent to which.
*/
static int DistinctCorners(HPOLYGON hp1, HPOLYGON hp2) {
const POLYGON *pp1, *pp2;
@@ -1593,7 +1593,7 @@ static PPOLYGON GetPolyEntry() {
/**
* Variation of GetPolyEntry from Tinsel 1 that splits up getting a new
- * polygon structure from initialising it
+ * polygon structure from initializing it
*/
static PPOLYGON CommonInits(PTYPE polyType, int pno, const Poly &ptp, bool bRestart) {
int i;
@@ -1657,14 +1657,14 @@ static void PseudoCenter(POLYGON *p) {
}
/**
- * Initialise an EXIT polygon.
+ * Initialize an EXIT polygon.
*/
static void InitExit(const Poly &ptp, int pno, bool bRestart) {
CommonInits(EXIT, pno, ptp, bRestart);
}
/**
- * Initialise a PATH or NPATH polygon.
+ * Initialize a PATH or NPATH polygon.
*/
static void InitPath(const Poly &ptp, bool NodePath, int pno, bool bRestart) {
PPOLYGON p = CommonInits(PATH, pno, ptp, bRestart);
@@ -1676,14 +1676,14 @@ static void InitPath(const Poly &ptp, bool NodePath, int pno, bool bRestart) {
/**
- * Initialise a BLOCKING polygon.
+ * Initialize a BLOCKING polygon.
*/
static void InitBlock(const Poly &ptp, int pno, bool bRestart) {
CommonInits(BLOCK, pno, ptp, bRestart);
}
/**
- * Initialise an extra BLOCKING polygon related to a moving actor.
+ * Initialize an extra BLOCKING polygon related to a moving actor.
* The width of the polygon depends on the width of the actor which is
* trying to walk through the actor you first thought of.
* This is for dynamic blocking.
@@ -1718,7 +1718,7 @@ HPOLYGON InitExtraBlock(PMOVER ca, PMOVER ta) {
}
/**
- * Initialise an EFFECT polygon.
+ * Initialize an EFFECT polygon.
*/
static void InitEffect(const Poly &ptp, int pno, bool bRestart) {
CommonInits(EFFECT, pno, ptp, bRestart);
@@ -1726,7 +1726,7 @@ static void InitEffect(const Poly &ptp, int pno, bool bRestart) {
/**
- * Initialise a REFER polygon.
+ * Initialize a REFER polygon.
*/
static void InitRefer(const Poly &ptp, int pno, bool bRestart) {
PPOLYGON p = CommonInits(REFER, pno, ptp, bRestart);
@@ -1736,7 +1736,7 @@ static void InitRefer(const Poly &ptp, int pno, bool bRestart) {
/**
- * Initialise a TAG polygon.
+ * Initialize a TAG polygon.
*/
static void InitTag(const Poly &ptp, int pno, bool bRestart) {
CommonInits(TAG, pno, ptp, bRestart);
@@ -1781,7 +1781,7 @@ static void KillDeadPolygons() {
}
/**
- * Called at the start of a scene to initialise the polys in that scene.
+ * Called at the start of a scene to initialize the polys in that scene.
*/
void InitPolygons(SCNHANDLE ph, int numPoly, bool bRestart) {
pHandle = ph;
diff --git a/engines/tinsel/savescn.h b/engines/tinsel/savescn.h
index 27840876f2..894af0d6b8 100644
--- a/engines/tinsel/savescn.h
+++ b/engines/tinsel/savescn.h
@@ -96,7 +96,7 @@ void ProcessSRQueue();
void RequestSaveGame(char *name, char *desc, SAVED_DATA *sd, int *ssCount, SAVED_DATA *ssData);
void RequestRestoreGame(int num, SAVED_DATA *sd, int *ssCount, SAVED_DATA *ssData);
-void InitialiseSaveScenes();
+void InitializeSaveScenes();
void FreeSaveScenes();
} // End of namespace Tinsel
diff --git a/engines/tinsel/scene.cpp b/engines/tinsel/scene.cpp
index f2c3bff1d5..89b0da7d65 100644
--- a/engines/tinsel/scene.cpp
+++ b/engines/tinsel/scene.cpp
@@ -201,8 +201,8 @@ void SendSceneTinselProcess(TINSEL_EVENT event) {
/**
* Get the SCENE_STRUC
- * Initialise polygons for the scene
- * Initialise the actors for this scene
+ * Initialize polygons for the scene
+ * Initialize the actors for this scene
* Run the appropriate entrance code (if any)
* Get the default refer type
*/
@@ -244,10 +244,10 @@ static void LoadScene(SCNHANDLE scene, int entry) {
if (entry == NO_ENTRY_NUM) {
// Restoring scene
- // Initialise all the polygons for this scene
+ // Initialize all the polygons for this scene
InitPolygons(FROM_LE_32(ss->hPoly), FROM_LE_32(ss->numPoly), true);
- // Initialise the actors for this scene
+ // Initialize the actors for this scene
StartTaggedActors(FROM_LE_32(ss->hTaggedActor), FROM_LE_32(ss->numTaggedActor), false);
if (TinselV2)
@@ -257,10 +257,10 @@ static void LoadScene(SCNHANDLE scene, int entry) {
} else {
// Genuine new scene
- // Initialise all the polygons for this scene
+ // Initialize all the polygons for this scene
InitPolygons(FROM_LE_32(ss->hPoly), FROM_LE_32(ss->numPoly), false);
- // Initialise the actors for this scene
+ // Initialize the actors for this scene
StartTaggedActors(FROM_LE_32(ss->hTaggedActor), FROM_LE_32(ss->numTaggedActor), true);
// Run the appropriate entrance code (if any)
diff --git a/engines/tinsel/scroll.cpp b/engines/tinsel/scroll.cpp
index 7637664163..d75e649be3 100644
--- a/engines/tinsel/scroll.cpp
+++ b/engines/tinsel/scroll.cpp
@@ -416,7 +416,7 @@ void ScrollProcess(CORO_PARAM, const void *) {
CORO_BEGIN_CODE(_ctx);
// In Tinsel v2, scenes may play movies, so the background may not always
- // already be initialised like it is in v1
+ // already be initialized like it is in v1
while (!GetBgObject())
CORO_SLEEP(1);
diff --git a/engines/tinsel/sysvar.cpp b/engines/tinsel/sysvar.cpp
index aa3fdeead8..88053f15c6 100644
--- a/engines/tinsel/sysvar.cpp
+++ b/engines/tinsel/sysvar.cpp
@@ -112,7 +112,7 @@ static SCNHANDLE systemStrings[SS_MAX_VALID]; // FIXME: Avoid non-const global v
//----------------- FUNCTIONS --------------------------------
/**
- * Initialises the system variable list
+ * Initializes the system variable list
*/
void InitSysVars() {
diff --git a/engines/tinsel/tinlib.cpp b/engines/tinsel/tinlib.cpp
index a5a0c73395..7613c1a897 100644
--- a/engines/tinsel/tinlib.cpp
+++ b/engines/tinsel/tinlib.cpp
@@ -2749,7 +2749,7 @@ static void SetTag(CORO_PARAM, int tagno) {
}
/**
- * Initialise a timer.
+ * Initialize a timer.
*/
static void SetTimer(int timerno, int start, bool up, bool frame) {
StartTimer(timerno, start, up != 0, frame != 0);
@@ -2999,7 +2999,7 @@ static void StartProcess(CORO_PARAM, uint32 procID) {
}
/**
- * Initialise a timer.
+ * Initialize a timer.
*/
static void StartTimerFn(int timerno, int start, bool up, int fs) {
StartTimer(timerno, start, up, fs);
diff --git a/engines/tinsel/tinsel.cpp b/engines/tinsel/tinsel.cpp
index 84a8ea8eb3..6c1898b08c 100644
--- a/engines/tinsel/tinsel.cpp
+++ b/engines/tinsel/tinsel.cpp
@@ -705,7 +705,7 @@ void LoadBasicChunks() {
int numObjects;
// Allocate RAM for savescene data
- InitialiseSaveScenes();
+ InitializeSaveScenes();
// CHUNK_TOTAL_ACTORS seems to be missing in the released version, hard coding a value
// TODO: Would be nice to just change 511 to MAX_SAVED_ALIVES
diff --git a/engines/tinsel/bmv.cpp b/engines/tinsel/bmv.cpp
index db56c5bbba..24d47b920f 100644
--- a/engines/tinsel/bmv.cpp
+++ b/engines/tinsel/bmv.cpp
@@ -385,7 +385,7 @@ void BMVPlayer::MoviePalette(int paletteOffset) {
SetTextPal(talkColor);
}
-void BMVPlayer::InitialiseMovieSound() {
+void BMVPlayer::InitializeMovieSound() {
_audioStream = Audio::makeQueuingAudioStream(22050, true);
audioStarted = false;
}
@@ -663,7 +663,7 @@ void BMVPlayer::LoadSlots(int number) {
/**
* Called from the foreground when starting playback of a movie.
*/
-void BMVPlayer::InitialiseBMV() {
+void BMVPlayer::InitializeBMV() {
if (!stream.open(szMovieFile))
error(CANNOT_FIND_FILE, szMovieFile);
@@ -680,7 +680,7 @@ void BMVPlayer::InitialiseBMV() {
// Pass the sceen buffer to the decompresser
InitBMV(screenBuffer);
// Initialise some stuff
nextUseOffset = 0;
nextSoundOffset = 0;
wrapUseOffset = -1;
@@ -705,8 +705,8 @@ void BMVPlayer::InitialiseBMV() {
while (numAdvancePackets < ADVANCE_SOUND)
LoadSlots(1);
- // Initialise the sound channel
- InitialiseMovieSound();
+ // Initialize the sound channel
+ InitializeMovieSound();
}
/**
@@ -1066,7 +1066,7 @@ void BMVPlayer::FettleBMV() {
// First time in with this movie
- InitialiseBMV();
+ InitializeBMV();
for (i = 0; i < ADVANCE_SOUND;) {
if (DoSoundFrame())
@@ -680,7 +680,7 @@ void BMVPlayer::InitialiseBMV() {
// Pass the sceen buffer to the decompresser
InitBMV(screenBuffer);
- // Initialise some stuff
+ // Initialize some stuff
nextUseOffset = 0;
nextSoundOffset = 0;
diff --git a/engines/tinsel/savescn.cpp b/engines/tinsel/savescn.cpp
index 7be24cc964..89d68a611e 100644
--- a/engines/tinsel/savescn.cpp
+++ b/engines/tinsel/savescn.cpp
@@ -150,14 +150,14 @@ void DoRestoreScene(SAVED_DATA *sd, bool bFadeOut) {
RestoreSceneCount = RS_COUNT; // Set restore scene count
}
-void InitialiseSaveScenes() {
+void InitializeSaveScenes() {
if (ssData == NULL) {
ssData = (SAVED_DATA *)calloc(MAX_NEST, sizeof(SAVED_DATA));
if (ssData == NULL) {
error("Cannot allocate memory for scene changes");
}
} else {
// Re-initialise - no scenes saved
savedSceneCount = 0;
}
}
@@ -150,14 +150,14 @@ void DoRestoreScene(SAVED_DATA *sd, bool bFadeOut) {
}
} else {
- // Re-initialise - no scenes saved
+ // Re-initialize - no scenes saved
savedSceneCount = 0;
}